(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('clip-path')) :
    typeof define === 'function' && define.amd ? define(['exports', 'clip-path'], factory) :
    (global = global || self, factory(global.index = {}, global.clipPath));
}(this, (function (exports, clipPath) { 'use strict';

    // Variable Section

    // Main Section
    var script = {
        name: 'CarouselDiagonal',
        props: {
            screens: {},
            sideWidth: { default: function () { return 5 } },
            marginTop: { default: function () { return 0 } },
            color: { default: function () { return '#AA0F2F' } },
            textPrev: { default: function () { return 'PREV' } },
            muted: {},
        },
        watch: {
            muted: function (val) {
                this.muted_ = val;
            },

            indexClick: function () {
                if (this.indexClick == null) {
                    var device = this.checkMobile();
                    if (device == 'ipad') {
                        var c = document.querySelector('#CarouselDiagonal').getElementsByClassName('screen');
                        var array = [
                            'clip-path: polygon(0% 0px, 100% 0px, 100% 100%, 0% 100%); z-index: 1; cursor: pointer;',
                            'clip-path: polygon(5% 0px, 100% 0px, 100% 100%, 35% 100%); z-index: 2; cursor: pointer;',
                            'clip-path: polygon(35% 0px, 100% 0px, 100% 100%, 65% 100%); z-index: 3; cursor: pointer;',
                            'clip-path: polygon(65% 0px, 100% 0px, 100% 100%, 95% 100%); z-index: 4; cursor: pointer;'
                        ];

                        setTimeout(function() {
                            c[0].style = '';
                            c[1].style = '';
                            c[2].style = '';
                            c[3].style = '';
                        }, 100);

                        setTimeout(function() {
                            c[2].style = array[2];
                        }, 200);

                        setTimeout(function() {
                            c[1].style = array[1];
                        }, 300);

                        setTimeout(function() {
                            c[0].style = array[0];
                        }, 400);

                        setTimeout(function() {
                            c[3].style = array[3];
                        }, 500);
                    }
                }
            }
        },
        data: function () {
            return {
                video: null,
                indexHover: null,
                indexClick: null,
                muted_: true,
                widthPointer: 0,
                leftPointer: 0,
            }
        },
        created: function created() {},
        methods: {
            refScreen: function refScreen (index) {
                return 'screen' + index
            },
            setHoverIndex: function setHoverIndex (index) {
                if (this.indexClick == null) {
                    this.indexHover = index;
                }
            },
            resetHoverIndex: function resetHoverIndex () {
                if (this.indexClick==null) {
                    this.indexHover = null;
                }
            },
            setClickIndex: function setClickIndex (index) {
                this.indexClick = index;
                this.play(index);
            },
            setNextClickIndex: function setNextClickIndex (index) {
                this.indexClick = index;
                this.indexClick = (this.indexClick+1) % this.countScreen;
            },
            resetClickIndex: function resetClickIndex () {
                this.indexClick = null;
                for (var i=0; i<this.screens.length; i++) {
                    var video = this.getVideo(i);
                    video.load();
                    try {
                      video.currentTime = 0;
                    } catch (e) {
                      video.addEventListener('canplay', function() {
                        video.currentTime = 0;
                      });
                    }
                }
            },
            leftTitle: function leftTitle (index) {
                // Check index
                if (this.isIE) {
                  return (index + 0.5) * this.widthScreenRect
                } else {
                  if (index === 0) {
                    return this.widthScreen/4 + this.sideWidth/2
                  } else if (index === this.screens.length-1) {
                    return 100 - this.widthScreen/4 - this.sideWidth/2
                  } else {
                    return index * this.widthScreen + this.sideWidth
                  }
                }
            },
            zIndexScreen: function zIndexScreen (index) {
                return index + 1
            },
            checkMobile: function checkMobile (){
                var varUA = navigator.userAgent.toLowerCase();
                if (varUA.indexOf('android') > -1) {
                    return "android"
                } else if (varUA.indexOf("iphone") > -1 || varUA.indexOf("ipad") > -1 || varUA.indexOf("ipod") > -1) {
                    return "ios"
                } else if (navigator.maxTouchPoints > 1) {
                    return "ipad"
                } else {
                    return "other"
                }    
            },
            clipPathScreen: function clipPathScreen (index) {
                var result;
                if (index === 0) {
                    return 'polygon(0% 0, 100% 0, 100% 100%, 0 100%)'
                }
                var top = ((index-1) * this.widthScreen + this.sideWidth);
                var bottom = (index * this.widthScreen + this.sideWidth);

                if (this.indexClick !== null && this.indexClick >= 0) {
                    if (index === this.indexClick) {
                        top = 0;
                        bottom = 0;
                    } else if (index > this.indexClick) {
                        top = 100;
                        bottom = 100;
                    } else {
                        top = 0;
                        bottom = 0;
                    }
                }
                if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {
                    if (index === this.indexHover) {
                        top -= this.sideWidth;
                        bottom -= this.sideWidth;
                    } else if (index === this.indexHover+1) {
                        top += this.sideWidth;
                        bottom += this.sideWidth;
                    }
                }
                // eslint-disable-next-line prefer-const
                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)';
                return result
            },
            clipScreen: function clipScreen (index) {
              var result;
              if (index === 0) {
                return 'rect( 0, 100vw, 100vh, 0 )'
              }
              var left = index * this.widthScreenRect;

              if (this.indexClick !== null && this.indexClick >= 0) {
                if (index <= this.indexClick) {
                  return 'rect( 0, 100vw, 100vh, 0 )'
                } else if (index > this.indexClick) {
                  return 'rect( 0, 100vw, 100vh, 100vw )'
                }
              }
              if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {
                if (index === this.indexHover) {
                  left -= this.sideWidth;
                } else if (index === this.indexHover+1) {
                  left += this.sideWidth;
                }
              }
              result = 'rect( 0, 100vw, 100vh, ' + left + 'vw )';
              return result
            },
            dataPolyclip: function dataPolyclip (index) {
              setTimeout(function () {
                clipPath.ClipPath('#screen'+index);
              }, 100);

              if (index === 0) {
                return '0% 0%, 100%, 0%, 100% 100%, 0% 100%'
              }
              var top = ((index-1) * this.widthScreen + this.sideWidth);
              var bottom = (index * this.widthScreen + this.sideWidth);

              if (this.indexClick !== null && this.indexClick >= 0) {
                if (index === this.indexClick) {
                  top = 0;
                  bottom = 0;
                } else if (index > this.indexClick) {
                  top = 100;
                  bottom = 100;
                } else {
                  top = 0;
                  bottom = 0;
                }
              }
              if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {
                if (index === this.indexHover) {
                  top -= this.sideWidth;
                  bottom -= this.sideWidth;
                } else if (index === this.indexHover+1) {
                  top += this.sideWidth;
                  bottom += this.sideWidth;
                }
              }
              return top + '% 0%, 100% 0%, 100% 100%, ' + bottom +'% 100%'
            },
            openLink: function openLink (screen) {
                if (this.indexClick != null && screen.link) {
                  // window.open(screen.link, '_blank')
                    window.open(screen.link, '_self');
                }
            },
            getVideo: function getVideo (index) {
                return this.$refs[this.refScreen(index)][0]
            },
            stop: function stop (index) {
                var video = this.getVideo(index);
                video.pause();
            },
            stopAll: function stopAll (index) {
                for (var i=0; i<this.screens.length; i++) {
                    if (index !== i){
                        this.stop(i);
                    }
                }
            },
            play: function play (index) {
                this.stopAll(index);
                var video = this.getVideo(index);
                try {
                  video.currentTime = 0;
                } catch (e) {
                  video.addEventListener('canplay', function() {
                    video.currentTime = 0;
                  });
                }
                video.play();
            },
            timeupdate: function timeupdate ($event) {
                var video = $event.target;
                this.widthPointer = this.widthPagination * (video ? video.currentTime / video.duration : 0);
                this.leftPointer = 'calc( ' + (this.widthPagination * this.indexClick) + '% - ' + (4 * this.indexClick) + 'px + ' + (this.marginPagination * 2 * this.indexClick) + 'px )';
            },
            ended: function ended (index) {
                if (this.indexClick != null) {
                    this.setNextClickIndex(index);
                }
                this.play(index);
            },
            toggleMute: function toggleMute () {
                this.muted_ = !this.muted_;
            },
            getDataActionCode: function getDataActionCode (index) {
                var screen = this.screens[index];
                return screen.subtitle + ' ' + screen.title
            },
            clickScreen: function clickScreen (index) {
                var screen = this.screens[index];
                if (this.indexClick!=null) {
                    this.openLink(screen);
                } else {
                    this.setClickIndex(index);
                }
            },
            styleScreen: function styleScreen (index) {
                var style = {
                    'z-index': this.zIndexScreen(index),
                };
                if (this.isIE) {
                  style['clip'] = this.clipScreen(index);
                } else {
                  style['clip-path'] = this.clipPathScreen(index);
                }
                return style
            }
        },
        computed: {
            isIE: function isIE () {
                if (this.$browserDetect.isIE)
                    { return this.$browserDetect.isIE }
                else { return false }
            },
            countScreen: function countScreen () {
                return this.screens.length
            },
            widthScreen: function widthScreen () {
                var sideWidth = 5;
                if( this.sideWidth>0 && this.sideWidth<100 ) {
                    sideWidth = this.sideWidth;
                }
                return (100 - sideWidth*2) / (this.screens.length-1)
            },
            widthScreenRect: function widthScreenRect () {
              return 100 / this.screens.length
            },
            screen: function screen () {
                if(this.indexClick!=null) {
                    return this.screens[this.indexClick]
                } else {
                    return null
                }
            },
            widthPagination: function widthPagination () {
                return (100 / this.countScreen)
            },
            isPartialSound: function isPartialSound () {
                var result = false;
                for (var i=0; i<this.countScreen; i++){
                    var screen = this.screens[i];
                    if(screen.isSound) {
                        result = true;
                    }
                }
                return result
            },
            marginPagination: function marginPagination () {
              return 4 / 2 * this.countScreen / (this.countScreen - 1) // 4 is margin
            }
        }
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
        if (typeof shadowMode !== 'boolean') {
            createInjectorSSR = createInjector;
            createInjector = shadowMode;
            shadowMode = false;
        }
        // Vue.extend constructor export interop.
        var options = typeof script === 'function' ? script.options : script;
        // render functions
        if (template && template.render) {
            options.render = template.render;
            options.staticRenderFns = template.staticRenderFns;
            options._compiled = true;
            // functional template
            if (isFunctionalTemplate) {
                options.functional = true;
            }
        }
        // scopedId
        if (scopeId) {
            options._scopeId = scopeId;
        }
        var hook;
        if (moduleIdentifier) {
            // server build
            hook = function (context) {
                // 2.3 injection
                context =
                    context || // cached call
                        (this.$vnode && this.$vnode.ssrContext) || // stateful
                        (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
                // 2.2 with runInNewContext: true
                if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                    context = __VUE_SSR_CONTEXT__;
                }
                // inject component styles
                if (style) {
                    style.call(this, createInjectorSSR(context));
                }
                // register component module identifier for async chunk inference
                if (context && context._registeredComponents) {
                    context._registeredComponents.add(moduleIdentifier);
                }
            };
            // used by ssr in case component is cached and beforeCreate
            // never gets called
            options._ssrRegister = hook;
        }
        else if (style) {
            hook = shadowMode
                ? function (context) {
                    style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
                }
                : function (context) {
                    style.call(this, createInjector(context));
                };
        }
        if (hook) {
            if (options.functional) {
                // register for functional component in vue file
                var originalRender = options.render;
                options.render = function renderWithStyleInjection(h, context) {
                    hook.call(context);
                    return originalRender(h, context);
                };
            }
            else {
                // inject component registration as beforeCreate hook
                var existing = options.beforeCreate;
                options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
            }
        }
        return script;
    }

    var isOldIE = typeof navigator !== 'undefined' &&
        /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
    function createInjector(context) {
        return function (id, style) { return addStyle(id, style); };
    }
    var HEAD;
    var styles = {};
    function addStyle(id, css) {
        var group = isOldIE ? css.media || 'default' : id;
        var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
        if (!style.ids.has(id)) {
            style.ids.add(id);
            var code = css.source;
            if (css.map) {
                // https://developer.chrome.com/devtools/docs/javascript-debugging
                // this makes source maps inside style tags work properly in Chrome
                code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
                // http://stackoverflow.com/a/26603875
                code +=
                    '\n/*# sourceMappingURL=data:application/json;base64,' +
                        btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                        ' */';
            }
            if (!style.element) {
                style.element = document.createElement('style');
                style.element.type = 'text/css';
                if (css.media)
                    { style.element.setAttribute('media', css.media); }
                if (HEAD === undefined) {
                    HEAD = document.head || document.getElementsByTagName('head')[0];
                }
                HEAD.appendChild(style.element);
            }
            if ('styleSheet' in style.element) {
                style.styles.push(code);
                style.element.styleSheet.cssText = style.styles
                    .filter(Boolean)
                    .join('\n');
            }
            else {
                var index = style.ids.size - 1;
                var textNode = document.createTextNode(code);
                var nodes = style.element.childNodes;
                if (nodes[index])
                    { style.element.removeChild(nodes[index]); }
                if (nodes.length)
                    { style.element.insertBefore(textNode, nodes[index]); }
                else
                    { style.element.appendChild(textNode); }
            }
        }
    }

    /* script */
    var __vue_script__ = script;

    /* template */
    var __vue_render__ = function() {
      var _vm = this;
      var _h = _vm.$createElement;
      var _c = _vm._self._c || _h;
      return _c(
        "div",
        {
          class: { clicked: _vm.indexClick !== null },
          attrs: { id: "CarouselDiagonal" },
          on: { mouseleave: _vm.resetHoverIndex }
        },
        [
          _vm._l(_vm.screens, function(screen, index) {
            return _c(
              "div",
              {
                key: index,
                staticClass: "screen",
                staticStyle: { cursor: "pointer" },
                style: _vm.styleScreen(index),
                attrs: {
                  id: "screen" + index,
                  "data-polyclip": "0, 10%, 50%, 0, 75%, 75%, 0, 80%"
                },
                on: {
                  mouseover: function($event) {
                    return _vm.setHoverIndex(index)
                  },
                  click: function($event) {
                    return _vm.clickScreen(index)
                  }
                }
              },
              [
                _c("transition", { attrs: { name: "fade" } }, [
                  _c("div", {
                    directives: [
                      {
                        name: "show",
                        rawName: "v-show",
                        value:
                          _vm.indexClick == null &&
                          _vm.indexHover !== null &&
                          _vm.indexHover !== index,
                        expression:
                          "\n                indexClick == null &&\n                indexHover !== null &&\n                indexHover !== index"
                      }
                    ],
                    staticClass: "dimmed",
                    staticStyle: { "pointer-events": "none" }
                  })
                ]),
                _vm._v(" "),
                screen.video
                  ? _c(
                      "video",
                      {
                        ref: _vm.refScreen(index),
                        refInFor: true,
                        staticClass: "b-img",
                        staticStyle: { "pointer-events": "none" },
                        attrs: {
                          poster: screen.poster,
                          preload: "metadata",
                          playsinline: ""
                        },
                        domProps: { muted: _vm.muted_ },
                        on: {
                          timeupdate: _vm.timeupdate,
                          ended: function($event) {
                            return _vm.ended(index)
                          }
                        }
                      },
                      [
                        _c("source", {
                          attrs: { src: screen.video, type: "video/mp4" }
                        })
                      ]
                    )
                  : _vm._e(),
                _vm._v(" "),
                screen.image
                  ? _c("img", {
                      ref: _vm.refScreen(index),
                      refInFor: true,
                      staticClass: "b-img",
                      attrs: { src: screen.image }
                    })
                  : _vm._e(),
                _vm._v(" "),
                _c(
                  "div",
                  {
                    staticClass: "title",
                    style: {
                      left: _vm.leftTitle(index) + "%",
                      "margin-top": _vm.marginTop + "px"
                    }
                  },
                  [
                    _c("div", { staticClass: "title1" }, [
                      _vm._v(_vm._s(screen.subtitle))
                    ]),
                    _c("br"),
                    _vm._v(" "),
                    _c("div", { staticClass: "title2" }, [
                      _vm._v(_vm._s(screen.title))
                    ])
                  ]
                )
              ],
              1
            )
          }),
          _vm._v(" "),
          _vm.screen
            ? _c("div", { staticClass: "bottom" }, [
                _c("div", { staticClass: "info" }, [
                  _c("div", { staticClass: "page" }, [
                    _c("span", [_vm._v(_vm._s(_vm.indexClick + 1))]),
                    _vm._v(" "),
                    _c("span", [_vm._v("/ " + _vm._s(_vm.screens.length))])
                  ]),
                  _vm._v(" "),
                  _c(
                    "button",
                    {
                      staticClass: "title",
                      on: {
                        click: function($event) {
                          return _vm.openLink(_vm.screen)
                        }
                      }
                    },
                    [
                      _vm._v(
                        "\n                " +
                          _vm._s(_vm.screen.subtitle) +
                          " " +
                          _vm._s(_vm.screen.title) +
                          "\n            "
                      )
                    ]
                  )
                ]),
                _vm._v(" "),
                _c(
                  "div",
                  { staticClass: "buttons" },
                  _vm._l(_vm.screens, function(screen, index) {
                    return _c("button", {
                      key: index,
                      style: { width: _vm.widthPagination + "%" },
                      attrs: { "data-action": _vm.getDataActionCode(index) },
                      on: {
                        click: function($event) {
                          return _vm.setClickIndex(index)
                        }
                      }
                    })
                  }),
                  0
                ),
                _vm._v(" "),
                _c(
                  "div",
                  {
                    staticClass: "paginations",
                    style: {
                      "clip-path": null
                    }
                  },
                  [
                    _vm._l(_vm.screens, function(screen, index) {
                      return _c("button", {
                        key: index,
                        staticClass: "pagination",
                        style: {
                          width: "calc(" + _vm.widthPagination + "% - 4px)",
                          marginLeft: index == 0 ? 0 : _vm.marginPagination + "px",
                          marginRight:
                            index == _vm.countScreen - 1
                              ? 0
                              : _vm.marginPagination + "px"
                        },
                        attrs: { "data-action": _vm.getDataActionCode(index) },
                        on: {
                          click: function($event) {
                            return _vm.setClickIndex(index)
                          }
                        }
                      })
                    }),
                    _vm._v(" "),
                    _c("div", {
                      staticClass: "pointer",
                      staticStyle: { "pointer-events": "none" },
                      style: {
                        width: _vm.widthPointer + "%",
                        left: _vm.leftPointer,
                        background: _vm.color
                      }
                    })
                  ],
                  2
                ),
                _vm._v(" "),
                _c(
                  "div",
                  { staticClass: "buttons" },
                  _vm._l(_vm.screens, function(screen, index) {
                    return _c("button", {
                      key: index,
                      style: { width: _vm.widthPagination + "%" },
                      attrs: { "data-action": _vm.getDataActionCode(index) },
                      on: {
                        click: function($event) {
                          return _vm.setClickIndex(index)
                        }
                      }
                    })
                  }),
                  0
                )
              ])
            : _vm._e(),
          _vm._v(" "),
          _c(
            "transition",
            { attrs: { name: "fade" } },
            [
              _vm._t("reset", [
                _vm.indexClick !== null
                  ? _c(
                      "button",
                      {
                        staticClass: "reset",
                        on: {
                          click: function($event) {
                            return _vm.resetClickIndex()
                          }
                        }
                      },
                      [
                        _c(
                          "svg",
                          {
                            attrs: {
                              xmlns: "http://www.w3.org/2000/svg",
                              width: "11.288",
                              height: "16",
                              viewBox: "0 0 11.028 19.228"
                            }
                          },
                          [
                            _c("path", {
                              attrs: {
                                fill: "none",
                                stroke: "#fff",
                                "stroke-linecap": "round",
                                "stroke-width": "2.5px",
                                d: "M15.7 23.9l-8.2-8.2 8.2-8.2",
                                transform: "translate(-6.086 -6.086)"
                              }
                            })
                          ]
                        ),
                        _vm._v(" "),
                        _c("span", [_vm._v(_vm._s(_vm.textPrev))])
                      ]
                    )
                  : _vm._e()
              ])
            ],
            2
          ),
          _vm._v(" "),
          !_vm.isPartialSound || (_vm.screen && _vm.screen.isSound)
            ? _vm._t("mute", [
                _c(
                  "button",
                  {
                    staticClass: "mute",
                    staticStyle: {
                      width: "40px",
                      height: "60px",
                      position: "absolute",
                      bottom: "calc(6% - 18px)",
                      right: "calc(20% - 50px)",
                      transition: "all 500ms",
                      opacity: "0.5",
                      "z-index": "1000"
                    },
                    attrs: {
                      "data-action": "mute",
                      onmouseover: "style.opacity=1",
                      onmouseleave: "style.opacity=0.5"
                    },
                    on: { click: _vm.toggleMute }
                  },
                  [
                    _vm.muted_
                      ? _c(
                          "svg",
                          {
                            attrs: {
                              width: "24",
                              height: "19",
                              viewBox: "0 0 24 19",
                              fill: "none",
                              xmlns: "http://www.w3.org/2000/svg"
                            }
                          },
                          [
                            _c("path", {
                              attrs: {
                                "fill-rule": "evenodd",
                                "clip-rule": "evenodd",
                                d:
                                  "M11.8331 0.0986395C12.1795 0.265097 12.3999 0.615389 12.4 0.999749L12.404 17.1837C12.4041 17.5682 12.1838 17.9187 11.8373 18.0852C11.4908 18.2518 11.0795 18.205 10.7793 17.9649L5.27322 13.56H1C0.447715 13.56 0 13.1123 0 12.56V5.624C0 5.07171 0.447715 4.624 1 4.624H5.26922L10.7753 0.219127C11.0754 -0.0209806 11.4866 -0.0678183 11.8331 0.0986395ZM10.4005 3.08021L6.24469 6.40487C6.06738 6.54672 5.84707 6.624 5.62 6.624H2V11.56H5.624C5.85107 11.56 6.07138 11.6373 6.2487 11.7791L10.4035 15.103L10.4005 3.08021ZM23.6701 4.91689C24.0606 5.30741 24.0606 5.94058 23.6701 6.3311L20.9092 9.092L23.6701 11.8529C24.0606 12.2434 24.0606 12.8766 23.6701 13.2671C23.2796 13.6576 22.6464 13.6576 22.2559 13.2671L19.495 10.5062L16.7341 13.2671C16.3436 13.6576 15.7104 13.6576 15.3199 13.2671C14.9293 12.8766 14.9293 12.2434 15.3199 11.8529L18.0808 9.092L15.3199 6.3311C14.9293 5.94058 14.9293 5.30741 15.3199 4.91689C15.7104 4.52636 16.3436 4.52636 16.7341 4.91689L19.495 7.67778L22.2559 4.91689C22.6464 4.52636 23.2796 4.52636 23.6701 4.91689Z",
                                fill: "white"
                              }
                            })
                          ]
                        )
                      : _c(
                          "svg",
                          {
                            attrs: {
                              width: "26",
                              height: "19",
                              viewBox: "0 0 26 19",
                              fill: "none",
                              xmlns: "http://www.w3.org/2000/svg"
                            }
                          },
                          [
                            _c("path", {
                              attrs: {
                                "fill-rule": "evenodd",
                                "clip-rule": "evenodd",
                                d:
                                  "M22.2545 0.301387C21.8687 -0.0937738 21.2356 -0.101336 20.8404 0.284496C20.4453 0.670328 20.4377 1.30345 20.8235 1.69861C22.8603 3.78464 24.0005 6.58452 24.0005 9.5C24.0005 12.4155 22.8603 15.2154 20.8235 17.3014C20.4377 17.6965 20.4453 18.3297 20.8404 18.7155C21.2356 19.1013 21.8687 19.0938 22.2545 18.6986C24.6561 16.239 26.0005 12.9376 26.0005 9.5C26.0005 6.06236 24.6561 2.76103 22.2545 0.301387ZM18.0816 4.54544C17.6958 4.15025 17.0627 4.14264 16.6675 4.52844C16.2723 4.91424 16.2647 5.54736 16.6505 5.94255C17.5776 6.89223 18.0966 8.16681 18.0966 9.494C18.0966 10.8212 17.5776 12.0958 16.6505 13.0454C16.2647 13.4406 16.2723 14.0738 16.6675 14.4596C17.0627 14.8454 17.6958 14.8377 18.0816 14.4426C19.3734 13.1193 20.0966 11.3433 20.0966 9.494C20.0966 7.6447 19.3734 5.86872 18.0816 4.54544ZM12.64 1.083C12.64 0.697093 12.4179 0.345625 12.0694 0.179903C11.7209 0.0141805 11.3082 0.0637829 11.0088 0.307356L5.37354 4.893H1C0.447715 4.893 0 5.34072 0 5.893V13.108C0 13.6603 0.447715 14.108 1 14.108H5.37354L11.0088 18.6936C11.3082 18.9372 11.7209 18.9868 12.0694 18.8211C12.4179 18.6554 12.64 18.3039 12.64 17.918V1.083ZM6.36017 6.66865L10.64 3.18599V15.815L6.36017 12.3324C6.18183 12.1872 5.95893 12.108 5.729 12.108H2V6.893H5.729C5.95893 6.893 6.18183 6.81377 6.36017 6.66865Z",
                                fill: "white"
                              }
                            })
                          ]
                        )
                  ]
                )
              ])
            : _vm._e()
        ],
        2
      )
    };
    var __vue_staticRenderFns__ = [];
    __vue_render__._withStripped = true;

      /* style */
      var __vue_inject_styles__ = function (inject) {
        if (!inject) { return }
        inject("data-v-2e4711a0_0", { source: "#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  background: #333333;\n  /*font-family: 'LG Smart' !important;*/\n}\n#CarouselDiagonal * {\n  font-family: inherit;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s ease;\n}\n#CarouselDiagonal .screen .dimmed {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  background-color: rgba(0, 0, 0, 0.4);\n  z-index: 10;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 11;\n  display: inline-block;\n  color: white;\n  text-align: left;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n  font-weight: 600;\n  /*font-family: 'Montserrat' !important;*/\n  text-shadow: 0 3px 6px rgba(0, 0, 0, 0.44);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 30px;\n  line-height: 37px;\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  position: absolute;\n  top: 37px;\n  left: 0;\n  font-size: 40px;\n  line-height: 49px;\n  float: left;\n}\n#CarouselDiagonal.clicked .screen .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .bottom {\n  position: absolute;\n  box-sizing: border-box;\n  bottom: 6%;\n  width: 100%;\n  float: left;\n  z-index: 999;\n}\n@media (max-width: 750px) {\n#CarouselDiagonal .bottom {\n    padding-left: 5%;\n    padding-right: 5%;\n}\n}\n@media (min-width: 750px) {\n#CarouselDiagonal .bottom {\n    padding-left: 20%;\n    padding-right: 20%;\n}\n}\n#CarouselDiagonal .bottom .info {\n  position: relative;\n  width: 100%;\n  height: 37px;\n  margin-bottom: 5px;\n  font-weight: 600;\n}\n#CarouselDiagonal .bottom .info .page {\n  float: left;\n  display: inline-block;\n  color: white;\n  font-size: 13px;\n  font-weight: 300;\n  line-height: 24px;\n  padding-top: 13px;\n}\n#CarouselDiagonal .bottom .info .page span:first-child {\n  font-size: 17px;\n  font-weight: 600;\n}\n#CarouselDiagonal .bottom .info .title {\n  box-sizing: border-box;\n  position: absolute;\n  right: 0;\n  bottom: 0;\n  border: solid 1px rgba(255, 255, 255, 0.5);\n  display: inline-block;\n  color: white;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 25px;\n  padding: 4px 12px;\n  transition: all 500ms;\n}\n#CarouselDiagonal .bottom .info .title:hover {\n  border: solid 1px rgba(255, 255, 255, 0);\n  background: rgba(255, 255, 255, 0.5);\n}\n#CarouselDiagonal .bottom .buttons {\n  width: 100%;\n  height: 10px;\n  clear: both;\n}\n#CarouselDiagonal .bottom .buttons button {\n  height: 100%;\n  float: left;\n}\n#CarouselDiagonal .bottom .paginations {\n  position: relative;\n  width: 100%;\n  height: 3px;\n  clear: both;\n  z-index: 99;\n}\n#CarouselDiagonal .bottom .paginations .pagination {\n  height: 100%;\n  background: white;\n  opacity: 0.3;\n  border: none;\n  float: left;\n  z-index: 1;\n}\n#CarouselDiagonal .bottom .paginations .pointer {\n  position: absolute;\n  height: 100%;\n  top: 0;\n  z-index: 2;\n  transition: all 250ms ease-out;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  top: 50%;\n  left: 3.6%;\n  z-index: 6;\n  color: white;\n  background: none;\n  padding: 10px;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 21px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  margin-left: 12px;\n  line-height: 18px;\n  top: -5px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 500ms;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: auto;\n  min-height: 100%;\n  -webkit-background-size: cover;\n  -moz-background-size: cover;\n  -o-background-size: cover;\n  background-size: cover;\n  -webkit-background-position: center center;\n  -moz-background-position: center center;\n  -o-background-position: center center;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 50%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::media-controls, #CarouselDiagonal video::-webkit-media-controls, #CarouselDiagonal video::-moz-media-controls, #CarouselDiagonal video::-o-media-controls, #CarouselDiagonal video::-ms-media-controls,\n#CarouselDiagonal video::media-controls-panel, #CarouselDiagonal video::-webkit-media-controls-panel,\n#CarouselDiagonal video::media-controls-play-button, #CarouselDiagonal video::-webkit-media-controls-play-button,\n#CarouselDiagonal video::media-controls-start-playback-button, #CarouselDiagonal video::-webkit-media-controls-start-playback-button,\n#CarouselDiagonal video::media-controls-volume-slider, #CarouselDiagonal video::-webkit-media-controls-volume-slider,\n#CarouselDiagonal video::media-controls-mute-button, #CarouselDiagonal video::-webkit-media-controls-mute-button,\n#CarouselDiagonal video::media-controls-timeline, #CarouselDiagonal video::-webkit-media-controls-timeline,\n#CarouselDiagonal video::media-controls-current-time-display, #CarouselDiagonal video::-webkit-media-controls-current-time-display {\n  display: none !important;\n  appearance: none !important;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */", map: {"version":3,"sources":["/Users/a/Project/OLED/vue-carousel-diagonal/src/components/CarouselDiagonal.vue","CarouselDiagonal.vue"],"names":[],"mappings":"AA6bA;EACA,kBAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;EACA,mBAAA;EACA,sCAAA;AC5bA;AD6bA;EACA,oBAAA;AC3bA;AD6bA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;EACA,gBAAA;EACA,uBAAA;AC3bA;AD6bA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,WAAA;EACA,YAAA;EACA,oCAAA;EACA,WAAA;AC3bA;AD+bA;EACA,kBAAA;EACA,QAAA;EACA,WAAA;EACA,qBAAA;EACA,YAAA;EACA,gBAAA;EACA,kBAAA;EACA,4CAAA;EACA,gBAAA;EACA,wCAAA;EACA,0CAAA;AC7bA;AD8bA;EACA,eAAA;EACA,iBAAA;EACA,WAAA;AC5bA;AD8bA;EACA,kBAAA;EACA,SAAA;EACA,OAAA;EACA,eAAA;EACA,iBAAA;EACA,WAAA;AC5bA;ADkcA;EACA,mBAAA;EACA,oBAAA;EACA,UAAA;EACA,uDAAA;AChcA;ADqcA;EACA,kBAAA;EACA,sBAAA;EACA,UAAA;EACA,WAAA;EAWA,WAAA;EACA,YAAA;AC7cA;ADmcA;AANA;IAOA,gBAAA;IACA,iBAAA;AChcE;AACF;ADicA;AAVA;IAWA,iBAAA;IACA,kBAAA;AC9bE;AACF;ADkcA;EACA,kBAAA;EACA,WAAA;EACA,YAAA;EACA,kBAAA;EACA,gBAAA;AChcA;ADicA;EACA,WAAA;EACA,qBAAA;EACA,YAAA;EACA,eAAA;EACA,gBAAA;EACA,iBAAA;EACA,iBAAA;AC/bA;ADicA;EACA,eAAA;EACA,gBAAA;AC/bA;ADmcA;EACA,sBAAA;EACA,kBAAA;EACA,QAAA;EACA,SAAA;EACA,0CAAA;EACA,qBAAA;EACA,YAAA;EACA,eAAA;EACA,gBAAA;EACA,iBAAA;EACA,iBAAA;EACA,qBAAA;ACjcA;ADkcA;EACA,wCAAA;EACA,oCAAA;AChcA;ADocA;EACA,WAAA;EACA,YAAA;EACA,WAAA;AClcA;ADmcA;EAAA,YAAA;EAAA,WAAA;AC/bA;ADicA;EACA,kBAAA;EACA,WAAA;EACA,WAAA;EACA,WAAA;EACA,WAAA;AC/bA;ADgcA;EACA,YAAA;EACA,iBAAA;EACA,YAAA;EACA,YAAA;EACA,WAAA;EACA,UAAA;AC9bA;ADgcA;EACA,kBAAA;EACA,YAAA;EACA,MAAA;EACA,UAAA;EACA,8BAAA;AC9bA;ADmcA;EACA,kBAAA;EACA,QAAA;EACA,UAAA;EACA,UAAA;EACA,YAAA;EACA,gBAAA;EACA,aAAA;EACA,eAAA;EACA,gBAAA;EACA,iBAAA;ACjcA;ADkcA;EAAA,WAAA;AC/bA;ADgcA;EACA,iBAAA;EACA,iBAAA;EACA,SAAA;AC9bA;ADmcA;EACA,kBAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;ACjcA;ADqcA;EACA,yBAAA;EACA,YAAA;ACncA;ADqcA;EACA,UAAA;ACncA;ADqcA;EACA,WAAA;EACA,YAAA;EACA,gBAAA;EACA,8BAAA;EACA,2BAAA;EACA,yBAAA;EACA,sBAAA;EACA,0CAAA;EACA,uCAAA;EACA,qCAAA;EACA,kCAAA;EACA,iBAAA;ACncA;ADqcA;EACA,YAAA;EACA,aAAA;EACA,gBAAA;EACA,eAAA;ACncA;ADscA;EACA,kBAAA;EACA,UAAA;EACA,WAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;EACA,gBAAA;EACA,WAAA;ACpcA;ADucA;;;;;;;;EAQA,wBAAA;EACA,2BAAA;ACrcA;;AAEA,+CAA+C","file":"CarouselDiagonal.vue","sourcesContent":["<script>\n    // Imports Section\n    import { ClipPath } from 'clip-path'\n\n    // Variable Section\n\n    // Main Section\n    export default {\n        name: 'CarouselDiagonal',\n        props: {\n            screens: {},\n            sideWidth: { default: function () { return 5 } },\n            marginTop: { default: function () { return 0 } },\n            color: { default: function () { return '#AA0F2F' } },\n            textPrev: { default: function () { return 'PREV' } },\n            muted: {},\n        },\n        watch: {\n            muted: function (val) {\n                this.muted_ = val\n            },\n\n            indexClick: function () {\n                if (this.indexClick == null) {\n                    var device = this.checkMobile()\n                    if (device == 'ipad') {\n                        var c = document.querySelector('#CarouselDiagonal').getElementsByClassName('screen');\n                        var array = [\n                            'clip-path: polygon(0% 0px, 100% 0px, 100% 100%, 0% 100%); z-index: 1; cursor: pointer;',\n                            'clip-path: polygon(5% 0px, 100% 0px, 100% 100%, 35% 100%); z-index: 2; cursor: pointer;',\n                            'clip-path: polygon(35% 0px, 100% 0px, 100% 100%, 65% 100%); z-index: 3; cursor: pointer;',\n                            'clip-path: polygon(65% 0px, 100% 0px, 100% 100%, 95% 100%); z-index: 4; cursor: pointer;'\n                        ]\n\n                        setTimeout(function() {\n                            c[0].style = ''\n                            c[1].style = ''\n                            c[2].style = ''\n                            c[3].style = ''\n                        }, 100)\n\n                        setTimeout(function() {\n                            c[2].style = array[2]\n                        }, 200)\n\n                        setTimeout(function() {\n                            c[1].style = array[1]\n                        }, 300)\n\n                        setTimeout(function() {\n                            c[0].style = array[0]\n                        }, 400)\n\n                        setTimeout(function() {\n                            c[3].style = array[3]\n                        }, 500)\n                    }\n                }\n            }\n        },\n        data: function () {\n            return {\n                video: null,\n                indexHover: null,\n                indexClick: null,\n                muted_: true,\n                widthPointer: 0,\n                leftPointer: 0,\n            }\n        },\n        created() {},\n        methods: {\n            refScreen (index) {\n                return 'screen' + index\n            },\n            setHoverIndex (index) {\n                if (this.indexClick == null) {\n                    this.indexHover = index\n                }\n            },\n            resetHoverIndex () {\n                if (this.indexClick==null) {\n                    this.indexHover = null\n                }\n            },\n            setClickIndex (index) {\n                this.indexClick = index\n                this.play(index)\n            },\n            setNextClickIndex (index) {\n                this.indexClick = index\n                this.indexClick = (this.indexClick+1) % this.countScreen\n            },\n            resetClickIndex () {\n                this.indexClick = null\n                for (var i=0; i<this.screens.length; i++) {\n                    var video = this.getVideo(i)\n                    video.load()\n                    try {\n                      video.currentTime = 0\n                    } catch (e) {\n                      video.addEventListener('canplay', function() {\n                        video.currentTime = 0\n                      })\n                    }\n                }\n            },\n            leftTitle (index) {\n                // Check index\n                if (this.isIE) {\n                  return (index + 0.5) * this.widthScreenRect\n                } else {\n                  if (index === 0) {\n                    return this.widthScreen/4 + this.sideWidth/2\n                  } else if (index === this.screens.length-1) {\n                    return 100 - this.widthScreen/4 - this.sideWidth/2\n                  } else {\n                    return index * this.widthScreen + this.sideWidth\n                  }\n                }\n            },\n            zIndexScreen (index) {\n                return index + 1\n            },\n            checkMobile (){\n                var varUA = navigator.userAgent.toLowerCase()\n                if (varUA.indexOf('android') > -1) {\n                    return \"android\"\n                } else if (varUA.indexOf(\"iphone\") > -1 || varUA.indexOf(\"ipad\") > -1 || varUA.indexOf(\"ipod\") > -1) {\n                    return \"ios\"\n                } else if (navigator.maxTouchPoints > 1) {\n                    return \"ipad\"\n                } else {\n                    return \"other\"\n                }    \n            },\n            clipPathScreen (index) {\n                var result\n                if (index === 0) {\n                    return 'polygon(0% 0, 100% 0, 100% 100%, 0 100%)'\n                }\n                var top = ((index-1) * this.widthScreen + this.sideWidth)\n                var bottom = (index * this.widthScreen + this.sideWidth)\n\n                if (this.indexClick !== null && this.indexClick >= 0) {\n                    if (index === this.indexClick) {\n                        top = 0\n                        bottom = 0\n                    } else if (index > this.indexClick) {\n                        top = 100\n                        bottom = 100\n                    } else {\n                        top = 0\n                        bottom = 0\n                    }\n                }\n                if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {\n                    if (index === this.indexHover) {\n                        top -= this.sideWidth\n                        bottom -= this.sideWidth\n                    } else if (index === this.indexHover+1) {\n                        top += this.sideWidth\n                        bottom += this.sideWidth\n                    }\n                }\n                // eslint-disable-next-line prefer-const\n                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)'\n                return result\n            },\n            clipScreen (index) {\n              var result\n              if (index === 0) {\n                return 'rect( 0, 100vw, 100vh, 0 )'\n              }\n              var left = index * this.widthScreenRect\n\n              if (this.indexClick !== null && this.indexClick >= 0) {\n                if (index <= this.indexClick) {\n                  return 'rect( 0, 100vw, 100vh, 0 )'\n                } else if (index > this.indexClick) {\n                  return 'rect( 0, 100vw, 100vh, 100vw )'\n                }\n              }\n              if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {\n                if (index === this.indexHover) {\n                  left -= this.sideWidth\n                } else if (index === this.indexHover+1) {\n                  left += this.sideWidth\n                }\n              }\n              result = 'rect( 0, 100vw, 100vh, ' + left + 'vw )'\n              return result\n            },\n            dataPolyclip (index) {\n              setTimeout(function () {\n                ClipPath('#screen'+index);\n              }, 100)\n\n              if (index === 0) {\n                return '0% 0%, 100%, 0%, 100% 100%, 0% 100%'\n              }\n              var top = ((index-1) * this.widthScreen + this.sideWidth)\n              var bottom = (index * this.widthScreen + this.sideWidth)\n\n              if (this.indexClick !== null && this.indexClick >= 0) {\n                if (index === this.indexClick) {\n                  top = 0\n                  bottom = 0\n                } else if (index > this.indexClick) {\n                  top = 100\n                  bottom = 100\n                } else {\n                  top = 0\n                  bottom = 0\n                }\n              }\n              if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {\n                if (index === this.indexHover) {\n                  top -= this.sideWidth\n                  bottom -= this.sideWidth\n                } else if (index === this.indexHover+1) {\n                  top += this.sideWidth\n                  bottom += this.sideWidth\n                }\n              }\n              return top + '% 0%, 100% 0%, 100% 100%, ' + bottom +'% 100%'\n            },\n            openLink (screen) {\n                if (this.indexClick != null && screen.link) {\n                  // window.open(screen.link, '_blank')\n                    window.open(screen.link, '_self')\n                }\n            },\n            getVideo (index) {\n                return this.$refs[this.refScreen(index)][0]\n            },\n            stop (index) {\n                var video = this.getVideo(index)\n                video.pause()\n            },\n            stopAll (index) {\n                for (var i=0; i<this.screens.length; i++) {\n                    if (index !== i){\n                        this.stop(i)\n                    }\n                }\n            },\n            play (index) {\n                this.stopAll(index)\n                var video = this.getVideo(index)\n                try {\n                  video.currentTime = 0\n                } catch (e) {\n                  video.addEventListener('canplay', function() {\n                    video.currentTime = 0\n                  })\n                }\n                video.play()\n            },\n            timeupdate ($event) {\n                var video = $event.target\n                this.widthPointer = this.widthPagination * (video ? video.currentTime / video.duration : 0)\n                this.leftPointer = 'calc( ' + (this.widthPagination * this.indexClick) + '% - ' + (4 * this.indexClick) + 'px + ' + (this.marginPagination * 2 * this.indexClick) + 'px )'\n            },\n            ended (index) {\n                if (this.indexClick != null) {\n                    this.setNextClickIndex(index)\n                }\n                this.play(index)\n            },\n            toggleMute () {\n                this.muted_ = !this.muted_\n            },\n            getDataActionCode (index) {\n                var screen = this.screens[index]\n                return screen.subtitle + ' ' + screen.title\n            },\n            clickScreen (index) {\n                var screen = this.screens[index]\n                if (this.indexClick!=null) {\n                    this.openLink(screen)\n                } else {\n                    this.setClickIndex(index)\n                }\n            },\n            styleScreen (index) {\n                let style = {\n                    'z-index': this.zIndexScreen(index),\n                }\n                if (this.isIE) {\n                  style['clip'] = this.clipScreen(index)\n                } else {\n                  style['clip-path'] = this.clipPathScreen(index)\n                }\n                return style\n            }\n        },\n        computed: {\n            isIE () {\n                if (this.$browserDetect.isIE)\n                    return this.$browserDetect.isIE\n                else return false\n            },\n            countScreen () {\n                return this.screens.length\n            },\n            widthScreen () {\n                var sideWidth = 5\n                if( this.sideWidth>0 && this.sideWidth<100 ) {\n                    sideWidth = this.sideWidth\n                }\n                return (100 - sideWidth*2) / (this.screens.length-1)\n            },\n            widthScreenRect () {\n              return 100 / this.screens.length\n            },\n            screen () {\n                if(this.indexClick!=null) {\n                    return this.screens[this.indexClick]\n                } else {\n                    return null\n                }\n            },\n            widthPagination () {\n                return (100 / this.countScreen)\n            },\n            isPartialSound () {\n                var result = false\n                for (var i=0; i<this.countScreen; i++){\n                    var screen = this.screens[i]\n                    if(screen.isSound) {\n                        result = true\n                    }\n                }\n                return result\n            },\n            marginPagination () {\n              return 4 / 2 * this.countScreen / (this.countScreen - 1) // 4 is margin\n            }\n        }\n    }\n</script>\n\n<template>\n    <div id=\"CarouselDiagonal\" :class=\"{ 'clicked': indexClick !== null }\" @mouseleave=\"resetHoverIndex\">\n        <!--Videos-->\n        <div v-for=\"(screen, index) in screens\"\n             :id=\"'screen'+index\"\n             :key=\"index\" class=\"screen\"\n             @mouseover=\"setHoverIndex(index)\"\n             @click=\"clickScreen(index)\"\n             :style=\"styleScreen(index)\"\n             style=\"cursor: pointer;\"\n             data-polyclip=\"0, 10%, 50%, 0, 75%, 75%, 0, 80%\">\n            <!--:data-clip=\"dataPolyclip(screen)\"-->\n            <transition name=\"fade\">\n                <div class=\"dimmed\" v-show=\"\n                    indexClick == null &&\n                    indexHover !== null &&\n                    indexHover !== index\"\n                    style=\"pointer-events: none;\">\n                </div>\n            </transition>\n            <!--Video-->\n            <video class=\"b-img\"\n                   style=\"pointer-events: none;\"\n                   v-if=\"screen.video\"\n                   :ref=\"refScreen(index)\"\n                   @timeupdate=\"timeupdate\"\n                   @ended=\"ended(index)\"\n                   :muted=\"muted_\"\n                   :poster=\"screen.poster\"\n                   preload=\"metadata\"\n                   playsinline>\n                <source :src=\"screen.video\" type=\"video/mp4\"></video>\n            <img class=\"b-img\" v-if=\"screen.image\" :ref=\"refScreen(index)\" :src=\"screen.image\"/>\n\n            <!--Title-->\n            <div class=\"title\" :style=\"{\n              'left': leftTitle(index) + '%',\n              'margin-top': marginTop+'px'\n            }\">\n                <div class=\"title1\">{{screen.subtitle}}</div><br/>\n                <div class=\"title2\">{{screen.title}}</div>\n            </div>\n        </div>\n\n        <!--Progress-->\n        <div class=\"bottom\" v-if=\"screen\">\n            <div class=\"info\">\n                <div class=\"page\"><span>{{indexClick+1}}</span> <span>/ {{screens.length}}</span></div>\n                <button class=\"title\"\n                        @click=\"openLink(screen)\">\n                    {{screen.subtitle}} {{screen.title}}\n                </button>\n            </div>\n            <div class=\"buttons\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" :data-action=\"getDataActionCode(index)\" @click=\"setClickIndex(index)\" :style=\"{width: widthPagination+'%'}\"></button>\n            </div>\n            <div class=\"paginations\" :style=\"{\n              'clip-path': null\n            }\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" :data-action=\"getDataActionCode(index)\" class=\"pagination\" @click=\"setClickIndex(index)\" :style=\"{\n                  width: 'calc(' + widthPagination + '% - 4px)',\n                  marginLeft: index==0 ? 0 : marginPagination+'px',\n                  marginRight: index==countScreen-1 ? 0 : marginPagination+'px',\n                }\"></button>\n                <div class=\"pointer\" :style=\"{ width: widthPointer + '%', left: leftPointer, background: color }\" style=\"pointer-events:none;\"></div>\n            </div>\n            <div class=\"buttons\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" :data-action=\"getDataActionCode(index)\" @click=\"setClickIndex(index)\" :style=\"{width: widthPagination+'%'}\"></button>\n            </div>\n        </div>\n\n        <!--Reset-->\n        <transition name=\"fade\">\n            <slot name=\"reset\">\n                <button class=\"reset\" @click=\"resetClickIndex()\" v-if=\"indexClick !== null\">\n                    <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"11.288\" height=\"16\" viewBox=\"0 0 11.028 19.228\">\n                        <path fill=\"none\" stroke=\"#fff\" stroke-linecap=\"round\" stroke-width=\"2.5px\" d=\"M15.7 23.9l-8.2-8.2 8.2-8.2\" transform=\"translate(-6.086 -6.086)\"/>\n                    </svg>\n                    <span>{{textPrev}}</span>\n                </button>\n            </slot>\n        </transition>\n\n        <!--Mute-->\n        <slot name=\"mute\" v-if=\"!isPartialSound || (screen && screen.isSound)\">\n            <button class=\"mute\"\n                    @click=\"toggleMute\"\n                    data-action=\"mute\"\n                    style=\"width: 40px; height: 60px; position: absolute; bottom: calc(6% - 18px); right: calc(20% - 50px); transition: all 500ms; opacity: 0.5; z-index: 1000;\" onmouseover=\"style.opacity=1\" onmouseleave=\"style.opacity=0.5\">\n                <svg v-if=\"muted_\" width=\"24\" height=\"19\" viewBox=\"0 0 24 19\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M11.8331 0.0986395C12.1795 0.265097 12.3999 0.615389 12.4 0.999749L12.404 17.1837C12.4041 17.5682 12.1838 17.9187 11.8373 18.0852C11.4908 18.2518 11.0795 18.205 10.7793 17.9649L5.27322 13.56H1C0.447715 13.56 0 13.1123 0 12.56V5.624C0 5.07171 0.447715 4.624 1 4.624H5.26922L10.7753 0.219127C11.0754 -0.0209806 11.4866 -0.0678183 11.8331 0.0986395ZM10.4005 3.08021L6.24469 6.40487C6.06738 6.54672 5.84707 6.624 5.62 6.624H2V11.56H5.624C5.85107 11.56 6.07138 11.6373 6.2487 11.7791L10.4035 15.103L10.4005 3.08021ZM23.6701 4.91689C24.0606 5.30741 24.0606 5.94058 23.6701 6.3311L20.9092 9.092L23.6701 11.8529C24.0606 12.2434 24.0606 12.8766 23.6701 13.2671C23.2796 13.6576 22.6464 13.6576 22.2559 13.2671L19.495 10.5062L16.7341 13.2671C16.3436 13.6576 15.7104 13.6576 15.3199 13.2671C14.9293 12.8766 14.9293 12.2434 15.3199 11.8529L18.0808 9.092L15.3199 6.3311C14.9293 5.94058 14.9293 5.30741 15.3199 4.91689C15.7104 4.52636 16.3436 4.52636 16.7341 4.91689L19.495 7.67778L22.2559 4.91689C22.6464 4.52636 23.2796 4.52636 23.6701 4.91689Z\" fill=\"white\"/>\n                </svg>\n                <svg v-else width=\"26\" height=\"19\" viewBox=\"0 0 26 19\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M22.2545 0.301387C21.8687 -0.0937738 21.2356 -0.101336 20.8404 0.284496C20.4453 0.670328 20.4377 1.30345 20.8235 1.69861C22.8603 3.78464 24.0005 6.58452 24.0005 9.5C24.0005 12.4155 22.8603 15.2154 20.8235 17.3014C20.4377 17.6965 20.4453 18.3297 20.8404 18.7155C21.2356 19.1013 21.8687 19.0938 22.2545 18.6986C24.6561 16.239 26.0005 12.9376 26.0005 9.5C26.0005 6.06236 24.6561 2.76103 22.2545 0.301387ZM18.0816 4.54544C17.6958 4.15025 17.0627 4.14264 16.6675 4.52844C16.2723 4.91424 16.2647 5.54736 16.6505 5.94255C17.5776 6.89223 18.0966 8.16681 18.0966 9.494C18.0966 10.8212 17.5776 12.0958 16.6505 13.0454C16.2647 13.4406 16.2723 14.0738 16.6675 14.4596C17.0627 14.8454 17.6958 14.8377 18.0816 14.4426C19.3734 13.1193 20.0966 11.3433 20.0966 9.494C20.0966 7.6447 19.3734 5.86872 18.0816 4.54544ZM12.64 1.083C12.64 0.697093 12.4179 0.345625 12.0694 0.179903C11.7209 0.0141805 11.3082 0.0637829 11.0088 0.307356L5.37354 4.893H1C0.447715 4.893 0 5.34072 0 5.893V13.108C0 13.6603 0.447715 14.108 1 14.108H5.37354L11.0088 18.6936C11.3082 18.9372 11.7209 18.9868 12.0694 18.8211C12.4179 18.6554 12.64 18.3039 12.64 17.918V1.083ZM6.36017 6.66865L10.64 3.18599V15.815L6.36017 12.3324C6.18183 12.1872 5.95893 12.108 5.729 12.108H2V6.893H5.729C5.95893 6.893 6.18183 6.81377 6.36017 6.66865Z\" fill=\"white\"/>\n                </svg>\n            </button>\n        </slot>\n\n    </div>\n</template>\n\n<style lang=\"scss\">\n    #CarouselDiagonal {\n        position: relative;\n        display: block;\n        float: left;\n        width: 100%;\n        height: 100%;\n        background: #333333;\n        /*font-family: 'LG Smart' !important;*/\n        * {\n            font-family: inherit;\n        }\n        .screen {\n            position: absolute;\n            top: 0;\n            left: 0;\n            display: block;\n            float: left;\n            width: 100%;\n            height: 100%;\n            overflow: hidden;\n            transition: all 1s ease;\n\n            .dimmed {\n                position:absolute;\n                top:0;\n                left:0;\n                width: 100%;\n                height: 100%;\n                background-color: rgba(0,0,0,0.4);\n                z-index: 10;\n                //transition: all 1s;\n            }\n\n            .title {\n                position: absolute;\n                top: 50%;\n                z-index: 11;\n                display: inline-block;\n                color: white;\n                text-align: left;\n                transition: all 2s;\n                transform: translateX(-50%) translateY(-50%);\n                font-weight: 600;\n                /*font-family: 'Montserrat' !important;*/\n                text-shadow: 0 3px 6px rgba(0, 0, 0, 0.44);\n                .title1 {\n                    font-size: 30px;\n                    line-height: 37px;\n                    float: left;\n                }\n                .title2 {\n                    position: absolute;\n                    top: 37px;\n                    left: 0;\n                    font-size: 40px;\n                    line-height: 49px;\n                    float: left;\n                }\n            }\n        }\n        &.clicked {\n            .screen {\n                .title {\n                    top:50% !important;\n                    left: 50% !important;\n                    opacity: 0;\n                    transform: translateX(-50%) translateY(-50%) !important;\n                }\n            }\n        }\n\n        .bottom {\n            position: absolute;\n            box-sizing: border-box;\n            bottom: 6%;\n            width: 100%;\n\n            @media (max-width: 750px) {\n                padding-left: 5%;\n                padding-right: 5%;\n            }\n            @media (min-width: 750px) {\n                padding-left: 20%;\n                padding-right: 20%;\n            }\n\n            float: left;\n            z-index: 999;\n            .info {\n                position: relative;\n                width: 100%;\n                height: 37px;\n                margin-bottom: 5px;\n                font-weight: 600;\n                .page {\n                    float: left;\n                    display: inline-block;\n                    color: white;\n                    font-size: 13px;\n                    font-weight: 300;\n                    line-height: 24px;\n                    padding-top: 13px;\n                    span {\n                        &:first-child {\n                            font-size: 17px;\n                            font-weight: 600;\n                        }\n                    }\n                }\n                .title {\n                    box-sizing: border-box;\n                    position: absolute;\n                    right: 0;\n                    bottom: 0;\n                    border: solid 1px rgba(255, 255, 255, 0.5);\n                    display: inline-block;\n                    color: white;\n                    font-size: 16px;\n                    font-weight: 500;\n                    line-height: 25px;\n                    padding: 4px 12px;\n                    transition: all 500ms;\n                    &:hover {\n                        border: solid 1px rgba(255, 255, 255, 0);\n                        background: rgba(255, 255, 255, 0.5);\n                    }\n                }\n            }\n            .buttons {\n                width: 100%;\n                height: 10px;\n                clear: both;\n                button { height: 100%; float: left; }\n            }\n            .paginations {\n                position: relative;\n                width: 100%;\n                height: 3px;\n                clear: both;\n                z-index: 99;\n                .pagination {\n                    height: 100%;\n                    background: white;\n                    opacity: 0.3;\n                    border: none;\n                    float: left;\n                    z-index: 1;\n                }\n                .pointer {\n                    position: absolute;\n                    height: 100%;\n                    top: 0;\n                    z-index: 2;\n                    transition: all 250ms ease-out;\n                }\n            }\n        }\n\n        .reset {\n            position: absolute;\n            top: 50%;\n            left: 3.6%;\n            z-index: 6;\n            color: white;\n            background: none;\n            padding: 10px;\n            font-size: 16px;\n            font-weight: 500;\n            line-height: 21px;\n            * { float: left; }\n            span {\n                margin-left: 12px;\n                line-height: 18px;\n                top: -5px;\n            }\n        }\n\n        button.mute {\n            svg {\n                position: absolute;\n                top: 50%;\n                left: 50%;\n                transform: translate(-50%, -50%);\n            }\n        }\n\n        .fade-enter-active, .fade-leave-active {\n            transition: opacity 500ms;\n            opacity: 100;\n        }\n        .fade-enter, .fade-leave-to /* .fade-leave-active below version 2.1.8 */ {\n            opacity: 0;\n        }\n        .b-img {\n            width: 100%;\n            height: auto;\n            min-height: 100%;\n            -webkit-background-size: cover;\n            -moz-background-size: cover;\n            -o-background-size: cover;\n            background-size: cover;\n            -webkit-background-position: center center;\n            -moz-background-position: center center;\n            -o-background-position: center center;\n            background-position: center center;\n            object-fit: cover;\n        }\n        button, button:focus {\n            border:none;\n            outline: none;\n            background: none;\n            cursor: pointer;\n        }\n\n        .link-button {\n            position: absolute;\n            width: 50%;\n            height: 50%;\n            top: 50%;\n            left: 50%;\n            transform: translate(-50%, -50%);\n            background: none;\n            z-index: 99;\n        }\n\n        video::media-controls, video::-webkit-media-controls, video::-moz-media-controls, video::-o-media-controls, video::-ms-media-controls,\n        video::media-controls-panel, video::-webkit-media-controls-panel,\n        video::media-controls-play-button, video::-webkit-media-controls-play-button,\n        video::media-controls-start-playback-button, video::-webkit-media-controls-start-playback-button,\n        video::media-controls-volume-slider, video::-webkit-media-controls-volume-slider,\n        video::media-controls-mute-button, video::-webkit-media-controls-mute-button,\n        video::media-controls-timeline, video::-webkit-media-controls-timeline,\n        video::media-controls-current-time-display, video::-webkit-media-controls-current-time-display {\n            display: none !important;\n            appearance: none !important;\n        }\n    }\n</style>","#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  background: #333333;\n  /*font-family: 'LG Smart' !important;*/\n}\n#CarouselDiagonal * {\n  font-family: inherit;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s ease;\n}\n#CarouselDiagonal .screen .dimmed {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  background-color: rgba(0, 0, 0, 0.4);\n  z-index: 10;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 11;\n  display: inline-block;\n  color: white;\n  text-align: left;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n  font-weight: 600;\n  /*font-family: 'Montserrat' !important;*/\n  text-shadow: 0 3px 6px rgba(0, 0, 0, 0.44);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 30px;\n  line-height: 37px;\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  position: absolute;\n  top: 37px;\n  left: 0;\n  font-size: 40px;\n  line-height: 49px;\n  float: left;\n}\n#CarouselDiagonal.clicked .screen .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .bottom {\n  position: absolute;\n  box-sizing: border-box;\n  bottom: 6%;\n  width: 100%;\n  float: left;\n  z-index: 999;\n}\n@media (max-width: 750px) {\n  #CarouselDiagonal .bottom {\n    padding-left: 5%;\n    padding-right: 5%;\n  }\n}\n@media (min-width: 750px) {\n  #CarouselDiagonal .bottom {\n    padding-left: 20%;\n    padding-right: 20%;\n  }\n}\n#CarouselDiagonal .bottom .info {\n  position: relative;\n  width: 100%;\n  height: 37px;\n  margin-bottom: 5px;\n  font-weight: 600;\n}\n#CarouselDiagonal .bottom .info .page {\n  float: left;\n  display: inline-block;\n  color: white;\n  font-size: 13px;\n  font-weight: 300;\n  line-height: 24px;\n  padding-top: 13px;\n}\n#CarouselDiagonal .bottom .info .page span:first-child {\n  font-size: 17px;\n  font-weight: 600;\n}\n#CarouselDiagonal .bottom .info .title {\n  box-sizing: border-box;\n  position: absolute;\n  right: 0;\n  bottom: 0;\n  border: solid 1px rgba(255, 255, 255, 0.5);\n  display: inline-block;\n  color: white;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 25px;\n  padding: 4px 12px;\n  transition: all 500ms;\n}\n#CarouselDiagonal .bottom .info .title:hover {\n  border: solid 1px rgba(255, 255, 255, 0);\n  background: rgba(255, 255, 255, 0.5);\n}\n#CarouselDiagonal .bottom .buttons {\n  width: 100%;\n  height: 10px;\n  clear: both;\n}\n#CarouselDiagonal .bottom .buttons button {\n  height: 100%;\n  float: left;\n}\n#CarouselDiagonal .bottom .paginations {\n  position: relative;\n  width: 100%;\n  height: 3px;\n  clear: both;\n  z-index: 99;\n}\n#CarouselDiagonal .bottom .paginations .pagination {\n  height: 100%;\n  background: white;\n  opacity: 0.3;\n  border: none;\n  float: left;\n  z-index: 1;\n}\n#CarouselDiagonal .bottom .paginations .pointer {\n  position: absolute;\n  height: 100%;\n  top: 0;\n  z-index: 2;\n  transition: all 250ms ease-out;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  top: 50%;\n  left: 3.6%;\n  z-index: 6;\n  color: white;\n  background: none;\n  padding: 10px;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 21px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  margin-left: 12px;\n  line-height: 18px;\n  top: -5px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 500ms;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: auto;\n  min-height: 100%;\n  -webkit-background-size: cover;\n  -moz-background-size: cover;\n  -o-background-size: cover;\n  background-size: cover;\n  -webkit-background-position: center center;\n  -moz-background-position: center center;\n  -o-background-position: center center;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 50%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::media-controls, #CarouselDiagonal video::-webkit-media-controls, #CarouselDiagonal video::-moz-media-controls, #CarouselDiagonal video::-o-media-controls, #CarouselDiagonal video::-ms-media-controls,\n#CarouselDiagonal video::media-controls-panel, #CarouselDiagonal video::-webkit-media-controls-panel,\n#CarouselDiagonal video::media-controls-play-button, #CarouselDiagonal video::-webkit-media-controls-play-button,\n#CarouselDiagonal video::media-controls-start-playback-button, #CarouselDiagonal video::-webkit-media-controls-start-playback-button,\n#CarouselDiagonal video::media-controls-volume-slider, #CarouselDiagonal video::-webkit-media-controls-volume-slider,\n#CarouselDiagonal video::media-controls-mute-button, #CarouselDiagonal video::-webkit-media-controls-mute-button,\n#CarouselDiagonal video::media-controls-timeline, #CarouselDiagonal video::-webkit-media-controls-timeline,\n#CarouselDiagonal video::media-controls-current-time-display, #CarouselDiagonal video::-webkit-media-controls-current-time-display {\n  display: none !important;\n  appearance: none !important;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */"]}, media: undefined });

      };
      /* scoped */
      var __vue_scope_id__ = undefined;
      /* module identifier */
      var __vue_module_identifier__ = undefined;
      /* functional template */
      var __vue_is_functional_template__ = false;
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      var __vue_component__ = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        false,
        createInjector,
        undefined,
        undefined
      );

    // Import vue component

    // Declare install function executed by Vue.use()
    function install(Vue) {
        if (install.installed) { return; }
        install.installed = true;
        Vue.component('DiagnoalScreen', __vue_component__);
    }

    // Create module definition for Vue.use()
    var plugin = {
        install: install,
    };

    // Auto-install when vue is found (eg. in browser via <script> tag)
    var GlobalVue = null;
    if (typeof window !== 'undefined') {
        GlobalVue = window.Vue;
    } else if (typeof global !== 'undefined') {
        GlobalVue = global.Vue;
    }
    if (GlobalVue) {
        GlobalVue.use(plugin);
    }

    exports.default = __vue_component__;
    exports.install = install;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
